==> imp-2.6.2_2.sierra.bottle.tar.gz: imp/2.6.2_2/include/IMP/core.h <==
/**
 *  \file IMP/core.h
 *  \brief Include all non-deprecated headers in IMP.core.
 *
 *  Copyright 2007-2016 IMP Inventors. All rights reserved.
 */

#ifndef IMP_CORE_H
#define IMP_CORE_H
#include <IMP/core/AngleRestraint.h>
#include <IMP/core/AngleTripletScore.h>
#include <IMP/core/AttributeSingletonScore.h>
#include <IMP/core/BallMover.h>
#include <IMP/core/BoundingBox3DSingletonScore.h>
#include <IMP/core/BoxSweepClosePairsFinder.h>
#include <IMP/core/CentroidOfRefined.h>
#include <IMP/core/ChecksScoreState.h>
#include <IMP/core/ChildrenRefiner.h>
#include <IMP/core/ClosePairsFinder.h>
#include <IMP/core/ClosePairsPairScore.h>
#include <IMP/core/ClosedCubicSpline.h>
#include <IMP/core/ConjugateGradients.h>
#include <IMP/core/ConnectivityRestraint.h>
#include <IMP/core/ConstantRestraint.h>
#include <IMP/core/Cosine.h>
#include <IMP/core/CoverRefined.h>
#include <IMP/core/DataObject.h>
#include <IMP/core/DerivativesFromRefined.h>
#include <IMP/core/DerivativesToRefined.h>
#include <IMP/core/DiameterRestraint.h>
#include <IMP/core/DihedralRestraint.h>
#include <IMP/core/DistancePairScore.h>
#include <IMP/core/DistanceRestraint.h>
#include <IMP/core/DistanceToSingletonScore.h>
#include <IMP/core/ExcludedVolumeRestraint.h>
#include <IMP/core/FixedRefiner.h>
#include <IMP/core/Gaussian.h>
#include <IMP/core/GridClosePairsFinder.h>
#include <IMP/core/Harmonic.h>
#include <IMP/core/HarmonicLowerBound.h>
#include <IMP/core/HarmonicUpperBound.h>
#include <IMP/core/HarmonicWell.h>
#include <IMP/core/Hierarchy.h>
#include <IMP/core/IncrementalScoringFunction.h>
#include <IMP/core/LeavesRefiner.h>
#include <IMP/core/Linear.h>
#include <IMP/core/MCCGSampler.h>
#include <IMP/core/MSConnectivityRestraint.h>
#include <IMP/core/MinimumRestraint.h>
#include <IMP/core/MonteCarlo.h>
#include <IMP/core/MonteCarloMover.h>
#include <IMP/core/MoveStatisticsScoreState.h>
#include <IMP/core/NearestNeighborsClosePairsFinder.h>
#include <IMP/core/NeighborsTable.h>
#include <IMP/core/NormalMover.h>
#include <IMP/core/OpenCubicSpline.h>
#include <IMP/core/PeriodicOptimizerState.h>
#include <IMP/core/QuadraticClosePairsFinder.h>
#include <IMP/core/RefinedPairsPairScore.h>
#include <IMP/core/RestraintsScoringFunction.h>
#include <IMP/core/RigidBodyAnglePairScore.h>
#include <IMP/core/RigidBodyDistancePairScore.h>
#include <IMP/core/RigidBodyMover.h>
#include <IMP/core/RigidBodyTunneler.h>
#include <IMP/core/RigidBodyUmbrella.h>
#include <IMP/core/RigidClosePairsFinder.h>
#include <IMP/core/SerialMover.h>
#include <IMP/core/SphereDistancePairScore.h>
#include <IMP/core/StatisticalPairScore.h>
#include <IMP/core/SteepestDescent.h>
#include <IMP/core/TableRefiner.h>
#include <IMP/core/Transform.h>
#include <IMP/core/TransformedDistancePairScore.h>
#include <IMP/core/TruncatedHarmonic.h>
#include <IMP/core/Typed.h>
#include <IMP/core/TypedPairScore.h>
#include <IMP/core/VolumeRestraint.h>
#include <IMP/core/WeightedDerivativesToRefined.h>
#include <IMP/core/XYZ.h>
#include <IMP/core/XYZR.h>
#include <IMP/core/blame.h>
#include <IMP/core/generic.h>
#include <IMP/core/model_statistics.h>
#include <IMP/core/predicates.h>
#include <IMP/core/python_only.h>
#include <IMP/core/rigid_bodies.h>
#include <IMP/core/rigid_body_geometries.h>
#include <IMP/core/symmetry.h>
#include <IMP/core/utility.h>
#include <IMP/core/SingletonConstraint.h>
#include <IMP/core/SingletonRestraint.h>
#include <IMP/core/singleton_predicates.h>
#include <IMP/core/PairConstraint.h>
#include <IMP/core/PairRestraint.h>
#include <IMP/core/pair_predicates.h>
#include <IMP/core/TripletConstraint.h>
#include <IMP/core/TripletRestraint.h>
#include <IMP/core/triplet_predicates.h>
#include <IMP/core/QuadConstraint.h>
#include <IMP/core/QuadRestraint.h>
#include <IMP/core/quad_predicates.h>
#endif /* IMP_CORE_H */

==> imp-2.7.0_3.sierra.bottle.tar.gz: imp/2.7.0_3/include/IMP/core.h <==
/**
 *  \file IMP/core.h
 *  \brief Include all non-deprecated headers in IMP.core.
 *
 *  Copyright 2007-2017 IMP Inventors. All rights reserved.
 */

#ifndef IMP_CORE_H
#define IMP_CORE_H
#include <IMP/core/AngleRestraint.h>
#include <IMP/core/AngleTripletScore.h>
#include <IMP/core/BallMover.h>
#include <IMP/core/BoundingBox3DSingletonScore.h>
#include <IMP/core/BoxSweepClosePairsFinder.h>
#include <IMP/core/CentroidOfRefined.h>
#include <IMP/core/ChecksScoreState.h>
#include <IMP/core/ChildrenRefiner.h>
#include <IMP/core/ClosePairsFinder.h>
#include <IMP/core/ClosePairsPairScore.h>
#include <IMP/core/ClosedCubicSpline.h>
#include <IMP/core/ConjugateGradients.h>
#include <IMP/core/ConnectivityRestraint.h>
#include <IMP/core/ConstantRestraint.h>
#include <IMP/core/Cosine.h>
#include <IMP/core/CoverRefined.h>
#include <IMP/core/DataObject.h>
#include <IMP/core/DerivativesFromRefined.h>
#include <IMP/core/DerivativesToRefined.h>
#include <IMP/core/DiameterRestraint.h>
#include <IMP/core/DihedralRestraint.h>
#include <IMP/core/DistancePairScore.h>
#include <IMP/core/DistanceRestraint.h>
#include <IMP/core/DistanceToSingletonScore.h>
#include <IMP/core/ExcludedVolumeRestraint.h>
#include <IMP/core/FixedRefiner.h>
#include <IMP/core/Gaussian.h>
#include <IMP/core/GenericAttributeSingletonScore.h>
#include <IMP/core/GridClosePairsFinder.h>
#include <IMP/core/Harmonic.h>
#include <IMP/core/HarmonicLowerBound.h>
#include <IMP/core/HarmonicUpperBound.h>
#include <IMP/core/HarmonicWell.h>
#include <IMP/core/Hierarchy.h>
#include <IMP/core/IncrementalScoringFunction.h>
#include <IMP/core/LeavesRefiner.h>
#include <IMP/core/Linear.h>
#include <IMP/core/MCCGSampler.h>
#include <IMP/core/MSConnectivityRestraint.h>
#include <IMP/core/MinimumRestraint.h>
#include <IMP/core/MonteCarlo.h>
#include <IMP/core/MonteCarloMover.h>
#include <IMP/core/MoveStatisticsScoreState.h>
#include <IMP/core/MultipleBinormalRestraint.h>
#include <IMP/core/NearestNeighborsClosePairsFinder.h>
#include <IMP/core/NeighborsTable.h>
#include <IMP/core/NormalMover.h>
#include <IMP/core/OpenCubicSpline.h>
#include <IMP/core/PeriodicOptimizerState.h>
#include <IMP/core/QuadraticClosePairsFinder.h>
#include <IMP/core/RefinedPairsPairScore.h>
#include <IMP/core/RestraintsScoringFunction.h>
#include <IMP/core/RigidBodyAnglePairScore.h>
#include <IMP/core/RigidBodyDistancePairScore.h>
#include <IMP/core/RigidBodyMover.h>
#include <IMP/core/RigidBodyTunneler.h>
#include <IMP/core/RigidBodyUmbrella.h>
#include <IMP/core/RigidClosePairsFinder.h>
#include <IMP/core/SerialMover.h>
#include <IMP/core/SphereDistancePairScore.h>
#include <IMP/core/StatisticalPairScore.h>
#include <IMP/core/SteepestDescent.h>
#include <IMP/core/SubsetMover.h>
#include <IMP/core/Surface.h>
#include <IMP/core/SurfaceDistancePairScore.h>
#include <IMP/core/SurfaceMover.h>
#include <IMP/core/SurfaceSymmetryConstraint.h>
#include <IMP/core/SurfaceTetheredChain.h>
#include <IMP/core/TableRefiner.h>
#include <IMP/core/Transform.h>
#include <IMP/core/TransformedDistancePairScore.h>
#include <IMP/core/TruncatedHarmonic.h>
#include <IMP/core/Typed.h>
#include <IMP/core/TypedPairScore.h>
#include <IMP/core/VolumeRestraint.h>
#include <IMP/core/WeightedDerivativesToRefined.h>
#include <IMP/core/WeightedSum.h>
#include <IMP/core/WeightedSumOfExponential.h>
#include <IMP/core/XYZ.h>
#include <IMP/core/XYZR.h>
#include <IMP/core/blame.h>
#include <IMP/core/generic.h>
#include <IMP/core/model_statistics.h>
#include <IMP/core/predicates.h>
#include <IMP/core/python_only.h>
#include <IMP/core/rigid_bodies.h>
#include <IMP/core/rigid_body_geometries.h>
#include <IMP/core/symmetry.h>
#include <IMP/core/utility.h>
#include <IMP/core/SingletonConstraint.h>
#include <IMP/core/SingletonRestraint.h>
#include <IMP/core/singleton_predicates.h>
#include <IMP/core/PairConstraint.h>
#include <IMP/core/PairRestraint.h>
#include <IMP/core/pair_predicates.h>
#include <IMP/core/TripletConstraint.h>
#include <IMP/core/TripletRestraint.h>
#include <IMP/core/triplet_predicates.h>
#include <IMP/core/QuadConstraint.h>
#include <IMP/core/QuadRestraint.h>
#include <IMP/core/quad_predicates.h>
#endif /* IMP_CORE_H */
